@@ -26,7 +26,11 @@ def test_completion_install_no_shell():
             "_TYPER_COMPLETE_TEST_DISABLE_SHELL_DETECTION": "True",
         },
     )
-    assert "Error: --install-completion option requires an argument" in result.stderr
+    # TODO: when deprecating Click 7, remove second option
+    assert (
+        "Error: Option '--install-completion' requires an argument" in result.stderr
+        or "Error: --install-completion option requires an argument" in result.stderr
+    )
 
 
 def test_completion_install_bash():
@@ -65,6 +69,8 @@ def test_completion_install_bash():
 def test_completion_install_zsh():
     completion_path: Path = Path.home() / ".zshrc"
     text = ""
+    if not completion_path.is_file():  # pragma: nocover
+        completion_path.write_text('echo "custom .zshrc"')
     if completion_path.is_file():
         text = completion_path.read_text()
     result = subprocess.run(
