@@ -1,8 +1,9 @@
 import subprocess
-from commands.context import tutorial003 as mod
 
 from typer.testing import CliRunner
 
+from docs_src.commands.context import tutorial003 as mod
+
 app = mod.app
 
 runner = CliRunner()
