@@ -1,8 +1,9 @@
 import subprocess
-from commands.one_or_multiple import tutorial001 as mod
 
 from typer.testing import CliRunner
 
+from docs_src.commands.one_or_multiple import tutorial001 as mod
+
 app = mod.app
 
 runner = CliRunner()
