@@ -3,7 +3,7 @@ import subprocess
 import typer
 from typer.testing import CliRunner
 
-from multiple_values.arguments_with_multiple_values import tutorial002 as mod
+from docs_src.multiple_values.arguments_with_multiple_values import tutorial002 as mod
 
 runner = CliRunner()
 app = typer.Typer()
@@ -29,7 +29,12 @@ def test_defaults():
 def test_invalid_args():
     result = runner.invoke(app, ["Draco", "Hagrid"])
     assert result.exit_code != 0
-    assert "Error: argument names takes 3 values" in result.stdout
+    # TODO: when deprecating Click 7, remove second option
+
+    assert (
+        "Error: Argument 'names' takes 3 values" in result.stdout
+        or "Error: argument names takes 3 values" in result.stdout
+    )
 
 
 def test_valid_args():
