@@ -34,7 +34,12 @@ def test_user_2():
 def test_invalid_user():
     result = runner.invoke(app, ["--user", "Camila", "50"])
     assert result.exit_code != 0
-    assert "Error: --user option requires 3 arguments" in result.output
+    # TODO: when deprecating Click 7, remove second option
+
+    assert (
+        "Error: Option '--user' requires 3 arguments" in result.output
+        or "Error: --user option requires 3 arguments" in result.output
+    )
 
 
 def test_script():
