@@ -3,7 +3,7 @@ import subprocess
 import typer
 from typer.testing import CliRunner
 
-from parameter_types.number import tutorial001 as mod
+from docs_src.parameter_types.number import tutorial001 as mod
 
 runner = CliRunner()
 
@@ -29,8 +29,13 @@ def test_params():
 def test_invalid_id():
     result = runner.invoke(app, ["1002"])
     assert result.exit_code != 0
+    # TODO: when deprecating Click 7, remove second option
     assert (
-        "Error: Invalid value for 'ID': 1002 is not in the valid range of 0 to 1000."
+        (
+            "Error: Invalid value for 'ID': 1002 is not in the range 0<=x<=1000."
+            in result.output
+        )
+        or "Error: Invalid value for 'ID': 1002 is not in the valid range of 0 to 1000."
         in result.output
     )
 
@@ -38,8 +43,12 @@ def test_invalid_id():
 def test_invalid_age():
     result = runner.invoke(app, ["5", "--age", "15"])
     assert result.exit_code != 0
+    # TODO: when deprecating Click 7, remove second option
+
     assert (
-        "Error: Invalid value for '--age': 15 is smaller than the minimum valid value 18."
+        "Error: Invalid value for '--age': 15 is not in the range x>=18"
+        in result.output
+        or "Error: Invalid value for '--age': 15 is smaller than the minimum valid value 18."
         in result.output
     )
 
@@ -47,8 +56,12 @@ def test_invalid_age():
 def test_invalid_score():
     result = runner.invoke(app, ["5", "--age", "20", "--score", "100.5"])
     assert result.exit_code != 0
+    # TODO: when deprecating Click 7, remove second option
+
     assert (
-        "Error: Invalid value for '--score': 100.5 is bigger than the maximum valid value 100."
+        "Error: Invalid value for '--score': 100.5 is not in the range x<=100."
+        in result.output
+        or "Error: Invalid value for '--score': 100.5 is bigger than the maximum valid value 100."
         in result.output
     )
 
