@@ -14,8 +14,12 @@ app.command()(mod.main)
 def test_invalid_id():
     result = runner.invoke(app, ["1002"])
     assert result.exit_code != 0
+    # TODO: when deprecating Click 7, remove second option
+
     assert (
-        "Error: Invalid value for 'ID': 1002 is not in the valid range of 0 to 1000."
+        "Error: Invalid value for 'ID': 1002 is not in the range 0<=x<=1000"
+        in result.output
+        or "Error: Invalid value for 'ID': 1002 is not in the valid range of 0 to 1000."
         in result.output
     )
 
