@@ -21,8 +21,12 @@ def test_main():
 def test_invalid_uuid():
     result = runner.invoke(app, ["7479706572-72756c6573"])
     assert result.exit_code != 0
+    # TODO: when deprecating Click 7, remove second option
+
     assert (
-        "Error: Invalid value for 'USER_ID': 7479706572-72756c6573 is not a valid UUID value"
+        "Error: Invalid value for 'USER_ID': '7479706572-72756c6573' is not a valid UUID"
+        in result.output
+        or "Error: Invalid value for 'USER_ID': 7479706572-72756c6573 is not a valid UUID value"
         in result.output
     )
 
