@@ -2,7 +2,7 @@ import subprocess
 
 from typer.testing import CliRunner
 
-from subcommands.tutorial002 import main as mod
+from docs_src.subcommands.tutorial002 import main as mod
 
 app = mod.app
 runner = CliRunner()
