@@ -2,16 +2,15 @@ import subprocess
 
 from click.testing import CliRunner
 
-from using_click import tutorial003 as mod
+from docs_src.using_click import tutorial003 as mod
 
 runner = CliRunner()
 
 
 def test_cli():
     result = runner.invoke(mod.typer_click_object, [])
-    assert "Usage" in result.stdout
-    assert "hello" in result.stdout
-    assert "top" in result.stdout
+    # TODO: when deprecating Click 7, remove second option
+    assert "Error: Missing command" in result.stdout or "Usage" in result.stdout
 
 
 def test_typer():
