@@ -16,6 +16,8 @@ from typing import (
 import click
 
 if TYPE_CHECKING:  # pragma: no cover
+    import click.shell_completion
+
     from .main import Typer  # noqa
 
 
@@ -87,7 +89,7 @@ class CommandInfo:
         *,
         cls: Optional[Type[click.Command]] = None,
         context_settings: Optional[Dict[Any, Any]] = None,
-        callback: Optional[Callable] = None,
+        callback: Optional[Callable[..., Any]] = None,
         help: Optional[str] = None,
         epilog: Optional[str] = None,
         short_help: Optional[str] = None,
@@ -119,13 +121,13 @@ class TyperInfo:
         name: Optional[str] = Default(None),
         cls: Optional[Type[click.Command]] = Default(None),
         invoke_without_command: bool = Default(False),
-        no_args_is_help: Optional[bool] = Default(None),
+        no_args_is_help: bool = Default(False),
         subcommand_metavar: Optional[str] = Default(None),
         chain: bool = Default(False),
-        result_callback: Optional[Callable] = Default(None),
+        result_callback: Optional[Callable[..., Any]] = Default(None),
         # Command
         context_settings: Optional[Dict[Any, Any]] = Default(None),
-        callback: Optional[Callable] = Default(None),
+        callback: Optional[Callable[..., Any]] = Default(None),
         help: Optional[str] = Default(None),
         epilog: Optional[str] = Default(None),
         short_help: Optional[str] = Default(None),
@@ -159,12 +161,18 @@ class ParameterInfo:
         *,
         default: Optional[Any] = None,
         param_decls: Optional[Sequence[str]] = None,
-        callback: Optional[Callable] = None,
+        callback: Optional[Callable[..., Any]] = None,
         metavar: Optional[str] = None,
         expose_value: bool = True,
         is_eager: bool = False,
         envvar: Optional[Union[str, List[str]]] = None,
-        autocompletion: Optional[Callable] = None,
+        shell_complete: Optional[
+            Callable[
+                [click.Context, click.Parameter, str],
+                Union[List["click.shell_completion.CompletionItem"], List[str]],
+            ]
+        ] = None,
+        autocompletion: Optional[Callable[..., Any]] = None,
         # TyperArgument
         show_default: Union[bool, str] = True,
         show_choices: bool = True,
@@ -180,11 +188,11 @@ class ParameterInfo:
         # DateTime
         formats: Optional[Union[List[str]]] = None,
         # File
-        mode: str = None,
+        mode: Optional[str] = None,
         encoding: Optional[str] = None,
         errors: Optional[str] = "strict",
         lazy: Optional[bool] = None,
-        atomic: Optional[bool] = False,
+        atomic: bool = False,
         # Path
         exists: bool = False,
         file_okay: bool = True,
@@ -202,6 +210,7 @@ class ParameterInfo:
         self.expose_value = expose_value
         self.is_eager = is_eager
         self.envvar = envvar
+        self.shell_complete = shell_complete
         self.autocompletion = autocompletion
         # TyperArgument
         self.show_default = show_default
@@ -241,16 +250,23 @@ class OptionInfo(ParameterInfo):
         # ParameterInfo
         default: Optional[Any] = None,
         param_decls: Optional[Sequence[str]] = None,
-        callback: Optional[Callable] = None,
+        callback: Optional[Callable[..., Any]] = None,
         metavar: Optional[str] = None,
         expose_value: bool = True,
         is_eager: bool = False,
         envvar: Optional[Union[str, List[str]]] = None,
-        autocompletion: Optional[Callable] = None,
+        shell_complete: Optional[
+            Callable[
+                [click.Context, click.Parameter, str],
+                Union[List["click.shell_completion.CompletionItem"], List[str]],
+            ]
+        ] = None,
+        autocompletion: Optional[Callable[..., Any]] = None,
         # Option
         show_default: bool = True,
         prompt: Union[bool, str] = False,
         confirmation_prompt: bool = False,
+        prompt_required: bool = True,
         hide_input: bool = False,
         is_flag: Optional[bool] = None,
         flag_value: Optional[Any] = None,
@@ -269,11 +285,11 @@ class OptionInfo(ParameterInfo):
         # DateTime
         formats: Optional[Union[List[str]]] = None,
         # File
-        mode: str = None,
+        mode: Optional[str] = None,
         encoding: Optional[str] = None,
         errors: Optional[str] = "strict",
         lazy: Optional[bool] = None,
-        atomic: Optional[bool] = False,
+        atomic: bool = False,
         # Path
         exists: bool = False,
         file_okay: bool = True,
@@ -292,6 +308,7 @@ class OptionInfo(ParameterInfo):
             expose_value=expose_value,
             is_eager=is_eager,
             envvar=envvar,
+            shell_complete=shell_complete,
             autocompletion=autocompletion,
             # TyperArgument
             show_default=show_default,
@@ -325,6 +342,7 @@ class OptionInfo(ParameterInfo):
         )
         self.prompt = prompt
         self.confirmation_prompt = confirmation_prompt
+        self.prompt_required = prompt_required
         self.hide_input = hide_input
         self.is_flag = is_flag
         self.flag_value = flag_value
@@ -339,12 +357,18 @@ class ArgumentInfo(ParameterInfo):
         # ParameterInfo
         default: Optional[Any] = None,
         param_decls: Optional[Sequence[str]] = None,
-        callback: Optional[Callable] = None,
+        callback: Optional[Callable[..., Any]] = None,
         metavar: Optional[str] = None,
         expose_value: bool = True,
         is_eager: bool = False,
         envvar: Optional[Union[str, List[str]]] = None,
-        autocompletion: Optional[Callable] = None,
+        shell_complete: Optional[
+            Callable[
+                [click.Context, click.Parameter, str],
+                Union[List["click.shell_completion.CompletionItem"], List[str]],
+            ]
+        ] = None,
+        autocompletion: Optional[Callable[..., Any]] = None,
         # TyperArgument
         show_default: Union[bool, str] = True,
         show_choices: bool = True,
@@ -360,11 +384,11 @@ class ArgumentInfo(ParameterInfo):
         # DateTime
         formats: Optional[Union[List[str]]] = None,
         # File
-        mode: str = None,
+        mode: Optional[str] = None,
         encoding: Optional[str] = None,
         errors: Optional[str] = "strict",
         lazy: Optional[bool] = None,
-        atomic: Optional[bool] = False,
+        atomic: bool = False,
         # Path
         exists: bool = False,
         file_okay: bool = True,
@@ -383,6 +407,7 @@ class ArgumentInfo(ParameterInfo):
             expose_value=expose_value,
             is_eager=is_eager,
             envvar=envvar,
+            shell_complete=shell_complete,
             autocompletion=autocompletion,
             # TyperArgument
             show_default=show_default,
