@@ -1,19 +1,20 @@
-from typing import IO, Any, Iterable, Mapping, Optional, Text, Union
+from typing import IO, Any, Mapping, Optional, Sequence, Text, Union
 
-from click.testing import CliRunner as ClickCliRunner, Result  # noqa
-from typer.main import Typer, get_command as _get_command
+from click.testing import CliRunner as ClickCliRunner  # noqa
+from click.testing import Result
+from typer.main import Typer
+from typer.main import get_command as _get_command
 
 
 class CliRunner(ClickCliRunner):
     def invoke(  # type: ignore
         self,
         app: Typer,
-        args: Optional[Union[str, Iterable[str]]] = None,
+        args: Optional[Union[str, Sequence[str]]] = None,
         input: Optional[Union[bytes, Text, IO[Any]]] = None,
         env: Optional[Mapping[str, str]] = None,
         catch_exceptions: bool = True,
         color: bool = False,
-        mix_stderr: bool = False,
         **extra: Any,
     ) -> Result:
         use_cli = _get_command(app)
@@ -24,6 +25,5 @@ class CliRunner(ClickCliRunner):
             env=env,
             catch_exceptions=catch_exceptions,
             color=color,
-            mix_stderr=mix_stderr,
             **extra,
         )
